@@ -17,4 +17,4 @@ except ImportError:
 
 from pygmyplotlib import *
 
-__all__ = ["xy_plot", "scatter", "histogram", "heat", "xy_heat"]
+__all__ = ["xy_plot", "scatter", "histogram", "heat_2d", "xy_heat"]
